try:
    from ._version import __version__
except ImportError:
    # Fallback when using the package in dev mode without installing
    # in editable mode with pip. It is highly recommended to install
    # the package from a stable release or in editable mode: https://pip.pypa.io/en/stable/topics/local-project-installs/#editable-installs
    import warnings

    warnings.warn("Importing 'amazon_sagemaker_jupyter_ai_q_developer' outside a proper installation.")
    __version__ = "dev"
from .handlers import setup_handlers
from .extension import SagemakerQChatExtension
from pathlib import Path
import json


def _jupyter_labextension_paths():
    HERE = Path(__file__).parent.resolve()

    with (HERE / "labextension" / "package.json").open(encoding="utf-8") as fid:
        package_json = json.load(fid)

    return [{"src": "labextension", "dest": package_json["name"]}]


def _jupyter_server_extension_points():
    return [{"module": "amazon_sagemaker_jupyter_ai_q_developer", "app": SagemakerQChatExtension}]


def _load_jupyter_server_extension(server_app):
    """Registers the API handler to receive HTTP requests from the frontend extension.

    Parameters
    ----------
    server_app: jupyterlab.labapp.LabApp
        JupyterLab application instance
    """
    name = "amazon_sagemaker_jupyter_ai_q_developer"
    server_app.log.info(f"Registered {name} server extension")
    web_app = server_app.web_app
    base_url = web_app.settings["base_url"]
    setup_handlers(server_app.web_app)


# For backward compatibility with notebook server - useful for Binder/JupyterHub
load_jupyter_server_extension = _load_jupyter_server_extension